@@ -25,44 +25,39 @@ class GetWeChEcomRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'alinlp', '2020-06-29', 'GetWeChEcom','alinlp')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Type(self):
+	def get_Type(self): # String
 		return self.get_body_params().get('Type')
 
-	def set_Type(self,Type):
+	def set_Type(self, Type):  # String
 		self.add_body_params('Type', Type)
-
-	def get_ServiceCode(self):
+	def get_ServiceCode(self): # String
 		return self.get_body_params().get('ServiceCode')
 
-	def set_ServiceCode(self,ServiceCode):
+	def set_ServiceCode(self, ServiceCode):  # String
 		self.add_body_params('ServiceCode', ServiceCode)
-
-	def get_Size(self):
+	def get_Size(self): # String
 		return self.get_body_params().get('Size')
 
-	def set_Size(self,Size):
+	def set_Size(self, Size):  # String
 		self.add_body_params('Size', Size)
-
-	def get_TokenizerId(self):
+	def get_TokenizerId(self): # String
 		return self.get_body_params().get('TokenizerId')
 
-	def set_TokenizerId(self,TokenizerId):
+	def set_TokenizerId(self, TokenizerId):  # String
 		self.add_body_params('TokenizerId', TokenizerId)
-
-	def get_Text(self):
+	def get_Text(self): # String
 		return self.get_body_params().get('Text')
 
-	def set_Text(self,Text):
+	def set_Text(self, Text):  # String
 		self.add_body_params('Text', Text)
-
-	def get_Operation(self):
+	def get_Operation(self): # String
 		return self.get_body_params().get('Operation')
 
-	def set_Operation(self,Operation):
-		self.add_body_params('Operation', Operation)
\ No newline at end of file
+	def set_Operation(self, Operation):  # String
+		self.add_body_params('Operation', Operation)
